@@ -21,11 +21,7 @@ json_load_params = {}
 
 python_file_defaults = {
     "files.associations": {"*.zcml": "xml"},
-    "files.exclude": {
-        "**/*.py[co]": True,
-        "**/*.so": True,
-        "**/__pycache__": True,
-    },
+    "files.exclude": {"**/*.py[co]": True, "**/*.so": True, "**/__pycache__": True},
 }
 
 
@@ -62,7 +58,7 @@ with io.open(
 
 class Recipe:
 
-    """zc.buildout recipe for sublimetext project settings:
+    """zc.buildout recipe for vscode project settings:
     """
 
     def __init__(self, buildout, name, options):
@@ -73,8 +69,6 @@ class Recipe:
         self.buildout, self.name, self.options = buildout, name, options
         self.logger = logging.getLogger(self.name)
 
-        self.egg = zc.recipe.egg.Egg(buildout, self.options["recipe"], options)
-
         self._set_defaults()
 
         self.settings_dir = os.path.join(options["project-root"], ".vscode")
@@ -95,19 +89,45 @@ class Recipe:
             p.strip() for p in self.options["packages"].splitlines() if p and p.strip()
         ]
 
+        # Make all other recipes dependent on us so they run first to
+        # ensure all implctly
+        # referenced parts are loaded
+        for part in self.buildout["buildout"].get("parts", "").split():
+            self.buildout.get(part)
+
     def install(self):
         """Let's build vscode settings file:
         This is the method will be called by buildout it-self and this recipe
         will generate or/update vscode setting file (.vscode/settings.json) based
         on provided options.
         """
+
+        if self.options.get("eggs"):
+            parts = [(self.name, self.options["recipe"], self.options)]
+        else:
+            parts = []
+            # get the parts including those not explicity in parts
+            # TODO: is there a way without a private method?
+            installed_part_options, _ = self.buildout._read_installed_part_options()
+            for part, options in installed_part_options.items():
+                if options is None or not options.get("recipe", None):
+                    continue
+                recipe = options["recipe"]
+                if ":" in recipe:
+                    recipe, _ = recipe.split(":")
+                parts.append((part, recipe, options))
+
         eggs_locations = set()
         develop_eggs_locations = set()
         develop_eggs = os.listdir(self.buildout["buildout"]["develop-eggs-directory"])
         develop_eggs = [dev_egg[:-9] for dev_egg in develop_eggs]
 
-        try:
-            requirements, ws = self.egg.working_set()
+        for part, recipe, options in parts:
+            egg = zc.recipe.egg.Egg(self.buildout, recipe, options)
+            try:
+                _, ws = egg.working_set()
+            except Exception as exc:
+                raise UserError(str(exc))
 
             for dist in ws.by_key.values():
 
@@ -120,9 +140,6 @@ class Recipe:
             for package in self.packages:
                 eggs_locations.add(package)
 
-        except Exception as exc:
-            raise UserError(str(exc))
-
         try:
             with io.open(
                 os.path.join(self.settings_dir, "settings.json"), "r", encoding="utf-8"
@@ -309,9 +326,22 @@ class Recipe:
                 options["omelette-location"]
             ] + develop_eggs_locations
 
+        # Needed for pylance
+        settings[mappings["analysis-extrapaths"]] = settings[
+            mappings["autocomplete-extrapaths"]
+        ]
+
         # Look on Jedi
-        if "jedi-enabled" in self.user_options:
+        if "jedi-enabled" in self.user_options and options["jedi-enabled"]:
+            # TODO: not even sure jediEnabled setting is supported anymore
             settings[mappings["jedi-enabled"]] = options["jedi-enabled"]
+            settings[mappings["languageserver"]] = "Jedi"
+            settings[mappings["completionsenabled"]] = False
+        else:
+            settings[mappings["jedi-enabled"]] = options["jedi-enabled"]
+            # TODO: or probably better to remove these settings?
+            settings[mappings["languageserver"]] = "Microsoft"
+            settings[mappings["completionsenabled"]] = True
 
         if options["jedi-path"]:
             settings[mappings["jedi-path"]] = self._resolve_executable_path(
@@ -349,9 +379,7 @@ class Recipe:
         self._sanitize_existing_linter_settings(
             existing_settings, "black", options, allow_key_error=True
         )
-        self._prepare_linter_settings(
-                settings, "black", options, allow_key_error=True
-            )
+        self._prepare_linter_settings(settings, "black", options, allow_key_error=True)
 
         return settings
 
