@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
 
 __author__ = """Md Nazrul Islam"""
-__email__ = 'email2nazrul@gmail.com'
-__version__ = '0.1.0'
+__email__ = "email2nazrul@gmail.com"
+__version__ = "0.1.0"
